/**
 * Adds input validation routines to make an input text accept only valid 
 * timestamps 
 */
loom.ui.TimePicker = Class.create({
	
	initialize: function(element, options) {
		this.options = Object.extend({
		}, options || {});
		this.element = element = $(element);
		element.maxlength || element.setAttribute('maxlength', 5);
		element.size || element.setAttribute('size', 5);
		element.observeMouseWheel(this.onMouseWheel.bindAsEventListener(this));
		element.observe('change', this.onChange.bindAsEventListener(this));
		element.observe('keypress', this.onKeypress.bindAsEventListener(this));
	},
	
	onMouseWheel: function(event) {
		console.debug(event);
	}, 
	
	/**
	 * Block any non-numeric keypress
	 */
	onKeypress: function(event) {
		var c = event.which || event.keyCode;
		( (c >= 65 && c <= 90) || (c >= 97 && c <= 122) ) && event.stop();
	},
	
	onChange: function(event) {
		var newValue = this.element.value;
		if (newValue != '') {
			var parsed = /^([\d ]?\d):(\d?\d)$/.exec(newValue);
			if (parsed) { // if the data is correct, format it
				newValue = parseInt(parsed[1]).toPaddedString(2) + ':' + parseInt(parsed[2]).toPaddedString(2);
			} 
		}
		this.element.value = newValue;
	}

});