/**
 * An implementation of the input prompt pattern:
 * 
 * http://ui-patterns.com/pattern/InputPrompt
 * 
 * This class will add a "prompt" css class and display the input title as value 
 * when the field loses focus if it's empty 
 */
loom.ui.InputPrompt = Class.create({
	
	/**
	 * @param form if not null, the form to apply the prompt to.
	 * Notice that new elements can be added latter using add()
	 */
	initialize: function(form, options) {
		options = Object.extend({
			selector: 'input[type=text], textarea' // the CSS selector to locate the promptable fields
		}, options || {});
		this.elements = $A([]);
		if (form) {
			form.select(options.selector).each(this.add.bind(this));
		}
		this.showAll();
		
		// listen to submit event
		form.observe('submit',  this.hideAll.bind(this));
		
		/*
		// listen to window exit event
		Event.observe(window, 'unload', this.hideAll.bind(this));
		
		 This seems excessive
		form.submit = form.submit.wrap(function(proceed) {
			this.hideAll();
			proceed();
		}.bind(this));
		*/
	},
	
	/**
	 * Display the prompt for  a single element
	 */
	show: function(element) {
		if (element.title && (element.value.strip().empty() || element.value == element.title)) {
			element.addClassName('prompt');
			element.value = element.title;
		}
	},
	
	/**
	 * Hide the prompt for  a single element
	 */
	hide: function(element) {
		if (element.hasClassName('prompt')) {
			element.value='';
			element.removeClassName('prompt');
		}
	},
	
	/**
	 * Display the prompt for all element
	 */
	showAll: function(element) {
		this.elements.each(this.show.bind(this));
	},
	
	/**
	 * Hide the prompt for all element
	 */
	hideAll: function(element) {
		this.elements.each(this.hide.bind(this));
	},
	
	add: function(element) {
		this.elements.push(element);
		element.observe('focus', this.hide.bind(this, element));
		element.observe('blur', this.show.bind(this, element));
	}
	
});

