/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotated methods calculate the CacheControl instance to be asociated to the current request.
 * CacheInterceptor will intercept the request just before event execution, and if the cache 
 * headers indicate that the browser version is still valid, the event will not be executed and the 
 * browser will receive a 304 (NOT MODIFIED) response instead.
 *   
 * @author Ignacio Coloma
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD})
@Documented
public @interface Cache {
	
    /** the list of events where to apply the caching method, empty for all. Accepts wildcards. */
    String[] on() default {};
    
    /** the list of events where to apply the caching method, empty for none. Accepts wildcards. */
    String[] except() default {};
	
}
