/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import java.util.Set;

import org.loom.interceptor.SecurityInterceptor;
import org.loom.mapping.Event;


/**
 * Processes security annotations.
 * Subclasses will provide concrete implementations for each security provider.
 * @author icoloma
 */
public abstract class AbstractSecurityAnnotationProcessor extends AbstractInjectedAnnotationProcessor<SecurityInterceptor> {
	
	public AbstractSecurityAnnotationProcessor() {
		super(SecurityInterceptor.class);
	}

	/** 
	 * Set the Roles that are allowed to call an event
	 */
	protected void setEventRoles(Event event, String[] roles) {
		removeInterceptor(event);
		SecurityInterceptor interceptor = getInstance();
		interceptor.setAllowedRoles(roles);
		event.getInterceptors().addListener(interceptor);
	}

	protected SecurityInterceptor findInterceptor(Event event) {
		Set<SecurityInterceptor> set = event.getInterceptors().findInterceptorsWithClass(SecurityInterceptor.class);
		return set.isEmpty()? null : set.iterator().next();
	}

	/**
	 * Removes the SecurityInterceptor on the supplied event
	 * @param event
	 */
	protected void removeInterceptor(Event event) {
		SecurityInterceptor interceptor = findInterceptor(event);
		if (interceptor != null) {
			event.getInterceptors().remove(interceptor);
		}
	}

}
