/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import java.util.List;
import java.util.SortedSet;
import java.util.TreeSet;

import org.loom.action.Action;
import org.loom.log.Log;
import org.loom.mapping.ActionMapping;
import org.loom.mapping.Event;

import com.google.common.collect.Lists;


/**
 * Repository of configured annotation processors
 * @author icoloma
 */
public class AnnotationProcessorRepository {

	/** processes annotations on methods and properties. By default it has the native loom annotations */
	private SortedSet<AnnotationProcessor> annotationProcessors= new TreeSet<AnnotationProcessor>();

	private static Log log = Log.getLog();

	public void addAnnotationProcessor(AnnotationProcessor processor) {
		annotationProcessors.add(processor);
	}
	
	public void process(ActionMapping mapping) {
		
		// process attribute annotations
		Class<? extends Action> actionClass = mapping.getActionClass();
		log.debug("Start processing annotations for ", actionClass.getName());
		VisitedClasses.initialize();
		VisitedClasses.add(actionClass);
		long t1 = System.currentTimeMillis();
		for (AnnotationProcessor processor : annotationProcessors) {
			// workaround: ConcurrentModificationException will happen if any processor modifies the list of events
			// TODO: there must be a better solution for this. Modifying the list of events does not look like a good thing
			List<Event> events = Lists.newArrayList(mapping.getEvents().values()); 
			for (Event event: events) {
				processor.process(event);
			}
		}
		long t2 = System.currentTimeMillis();
		log.debug("Processed ", mapping.getEvents().size(), " events in ", (t2 - t1), " milliseconds");
		
		// the list of reloading classes will be set to the list of visited classes
		mapping.setReloadingClasses(VisitedClasses.get());
	}
	
	public void setAnnotationProcessors(SortedSet<AnnotationProcessor> annotationProcessors) {
		this.annotationProcessors = annotationProcessors;
	}
	
	public SortedSet<AnnotationProcessor> getAnnotationProcessors() {
		return annotationProcessors;
	}

}
