/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.annotation.validation.FileValidation;
import org.loom.annotation.validation.FileValidations;
import org.loom.annotation.validation.ImageValidation;
import org.loom.interceptor.FileValidationInterceptor;
import org.loom.mapping.Event;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;


/**
 * Processes {@link ImageValidation} annotations
 * 
 * @author Rafael Serrano
 *
 */
@Component
public class FileValidationAnnotationProcessor extends AbstractAnnotationProcessor implements ApplicationContextAware {
	
	/** the spring {@link ApplicationContext} instance */ 
	private ApplicationContext applicationContext;

	/** the injected bean name */
	private String interceptorBeanName = "FileValidationInterceptor";
	
	@Override
	public void process(Event event) {
		FileValidation fileValidation = event.getJavaMethod().getAnnotation(FileValidation.class);
		if (fileValidation != null) {
			processAnnotation(event, fileValidation);
		}
		FileValidations fileValidations = event.getJavaMethod().getAnnotation(FileValidations.class);
		if (fileValidations != null) {
			for (FileValidation singleValidation : fileValidations.value()) {
				processAnnotation(event, singleValidation);
			}
		}
	}

	private void processAnnotation(Event event, FileValidation annotation) {
		FileValidationInterceptor interceptor = getInstance();
		interceptor.setParameterName(annotation.parameterName());
		if (annotation.maxFileSize() != -1) {
			interceptor.setMaxFileSize(annotation.maxFileSize());
		}
		interceptor.setAllowedFormats(annotation.formats());
		event.addInterceptor(interceptor);
	}

	protected FileValidationInterceptor getInstance() {
		return (FileValidationInterceptor) applicationContext.getBean(interceptorBeanName);
	}

	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext = applicationContext;
	}

	public void setInterceptorBeanName(String beanName) {
		this.interceptorBeanName = beanName;
	}
	

}
