/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.action.Action;
import org.loom.annotation.SSLPolicyType;
import org.loom.config.Config;
import org.loom.interceptor.SSLPolicyInterceptor;
import org.loom.mapping.Event;
import org.springframework.stereotype.Component;


/**
 * Processes the {@link org.loom.annotation.SSLPolicy} annotation
 * @author icoloma
 *
 */
@Component
public class SSLPolicyAnnotationProcessor extends AbstractInjectedAnnotationProcessor<SSLPolicyInterceptor> {

	private SSLPolicyType defaultPolicy;
	
	public SSLPolicyAnnotationProcessor() {
		super(SSLPolicyInterceptor.class);
	}

	@Override
	public void process(Event event) {
		
		org.loom.annotation.SSLPolicy annotation = event.getJavaMethod().getAnnotation(org.loom.annotation.SSLPolicy.class);
		if (annotation != null) { 
			// event policy
			setPolicy(event, annotation.value());
		} else {
			Class<? extends Action> actionClass = event.getActionMapping().getActionClass();
			annotation = actionClass.getAnnotation(org.loom.annotation.SSLPolicy.class);
			if (annotation != null) {
				// class policy
				setPolicy(event, annotation.value());
			} else {
				// default policy
				SSLPolicyType defaultPolicy = this.defaultPolicy != null? this.defaultPolicy : Config.getInstance().getDefaultSSLPolicy();
				setPolicy(event, defaultPolicy);
			}
		}
	}
	
	private void setPolicy(Event event, SSLPolicyType policy) {
		if (policy != SSLPolicyType.DO_NOT_MODIFY) {
			SSLPolicyInterceptor interceptor = getInstance();
			interceptor.setPolicy(policy);
			event.addInterceptor(interceptor);
		}
	}

	public void setDefaultPolicy(SSLPolicyType defaultPolicy) {
		this.defaultPolicy = defaultPolicy;
	}


}
