/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.validation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Recursively process annotations inside the annotated attribute class.
 * 
 * @author Ignacio Coloma
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.FIELD, ElementType.METHOD, ElementType.PARAMETER})
@Documented
public @interface NestedAnnotations {

    /** the list of events in which this validation takes place, empty for all (default empty) */
    String[] on() default {};
    
    /** the list of events in which this validation does NOT place, empty for none (default empty) */
    String[] except() default {};
    
    /** the list of properties that should be processed, empty for all (default empty) */
    String[] includeProperties() default {};
    
    /** the list of properties that should not be processed, empty for none (default empty) */
    String[] excludeProperties() default {};

}
