package org.loom.converter;

import java.util.Collection;
import java.util.Map;

import org.codehaus.jackson.map.type.TypeFactory;
import org.codehaus.jackson.type.JavaType;
import org.loom.annotation.JSON;
import org.loom.binding.AnnotationContainer;
import org.loom.config.Config;

public class JsonConverterFactory implements AnnotationDrivenConverterFactory<JSON> {

	public Class<JSON> getAnnotationClass() {
		return JSON.class;
	}

	@SuppressWarnings("unchecked")
	public Converter getConverter(AnnotationContainer container, JSON annotation) {
		Class propertyClass = container.getPropertyClass();
		JsonConverter jc = new JsonConverter(propertyClass);
		jc.setMapper(Config.getInstance().getObjectMapper());
		
		JavaType type;
		if (Collection.class.isAssignableFrom(propertyClass)) { 
			type = TypeFactory.collectionType(propertyClass, container.getItemMetadata(0).getItemClass());
		} else if (propertyClass.isArray()) {
			type = TypeFactory.arrayType(propertyClass);
		} else if (Map.class.isAssignableFrom(propertyClass)) {
			type = TypeFactory.mapType(propertyClass, container.getItemMetadata(0).getItemClass(), container.getItemMetadata(1).getItemClass());
		} else {
			type = TypeFactory.type(propertyClass);
		}
		jc.setJavaType(type);
		return jc;
	}

}
