/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

/**
 * Interface implemented by those Converters that are not aware of the 
 * input locale, so they will return the same converted value for the same input string
 * no matter which locale is selected by the user.
 * 
 * These converters are used when the input value is not extracted from a request object, e.g. 
 * the value property of an InputCheckbox tag.  
 * @author icoloma
 */
public interface LocaleUnawareConverter extends Converter {

	/**
	 * Perform the conversion. If the input data is not valid, will throw a RuntimeException.
	 */
	public Object getAsObject(String text);
	
}
