package org.loom.exception;

import java.io.IOException;

import javax.servlet.ServletException;

import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;

/**
 * Translates an application-produced Exception into one that can be handled by Loom 
 * @author icoloma
 *
 */
public interface ExceptionHandler {

	public void handle(LoomServletRequest request, LoomServletResponse response, Throwable exception) throws IOException, ServletException;
	
	/**
	 * Redirect to the source form page (extracted using the REFERER header). This method is invoked 
	 * if the request cannot be processed due to 
	 * user-introduced errors (such as conversion or validation errors).  The request gets redirected to 
	 * the source page, storing the current request data and error messages in the flash context to be 
	 * restored later.
	 * @throws ServletException 
	 * @throws UnhandledValidationErrorsException if the source page cannot be identified 
	 */
	public void redirectWithErrors(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException;

}
