/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.exception;

import javax.persistence.PersistenceException;

import org.loom.i18n.Message;

/**
 * Exceptions that may be raised when managing entities
 * 
 * @author Rafael Serrano
 */
public class LocaleAwarePersistenceException extends PersistenceException implements LocaleAwareThrowable {

	/** class of the handled entity */
	private Class<?> entityClass;
	
	/** the message key to be looked for in the MessagesRepository */
	private String messageKey;
	
	public LocaleAwarePersistenceException(Class<?> entityClass, String message, String messageKey) {
		this(entityClass, message, messageKey, null);
	}
		
	public LocaleAwarePersistenceException(Class<?> entityClass, String message, String messageKey, Throwable cause) {
		super(message, cause);
		this.messageKey = messageKey;
		this.entityClass = entityClass;
	}
	
	public Message getLocaleAwareMessage() {
		Message result = new Message(messageKey);
		result.addArg("exception", this);
		addTranslatedArgs(result);
		return result;
	}
	
	public void addTranslatedArgs(Message message) {
		message.addTranslatedArg("entityName", entityClass.getName());
	}

	public Class<?> getEntityClass() {
		return entityClass;
	}
	
}
