/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.exception;

/**
 * Exception thrown when an optimistic locking conflict occurs.
 * 
 * @author Rafael Serrano
 */
public class OptimisticLockException extends LocaleAwarePersistenceException {

	/** vesion stored in DB */
	private Object dbVersion;
	
	/** version to set */
	private Object newVersion;
	
	public OptimisticLockException(Class<?> entityClass, Object dbVersion, Object newVersion) {
		this(entityClass, dbVersion, newVersion, null);
	}

	public OptimisticLockException(Class<?> entityClass, Object dbVersion, Object newVersion,
			Throwable cause) {
		super(entityClass, "Instance of " + entityClass.getName() + " version numbers do not match:  "
				+ dbVersion + ", " + newVersion, "persistence.optimisticLock",
				cause);
		this.dbVersion = dbVersion;
		this.newVersion = newVersion;
	}

	public Object getDbVersion() {
		return dbVersion;
	}

	public Object getNewVersion() {
		return newVersion;
	}

}
