/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.i18n;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.mvel2.MVEL;
import org.mvel2.integration.impl.MapVariableResolverFactory;

/**
 * The compiled template of a message.
 * @author Ignacio Coloma
 */
@SuppressWarnings("unchecked")
public class CompiledMessage {

	/** the list of parts (String or MVEL CompiledStatement) */
	private List parts = new ArrayList();
	
	/**
	 * @return the message after replacing all the parameters with the provided values
	 */
	public String eval(Map<String, Object> params) {
		StringBuilder builder = new StringBuilder();
		MapVariableResolverFactory resolver = new MapVariableResolverFactory(params);
		for (Object part : parts) {
			if (part instanceof String) {
				builder.append((String)part);
			} else {
				builder.append(MVEL.executeExpression(part, resolver));
			}
		}
		return builder.toString();
	}
	
	public void addString(String part) {
		parts.add(part);
	}
	
	public void addCompiledExpression(String expression) {
		parts.add(MVEL.compileExpression(expression));
	}
	
	public List getParts() {
		return parts;
	}

	public String applyTo() {
		return null;
	}
	
}
