/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.i18n;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Receives a String and returns a CompiledMessage
 * @author Ignacio Coloma
 */
public class MessageCompiler {

	/** pattern that matches any parameter such as ${param.name} or $param */
	private static Pattern pattern = Pattern.compile("\\$(\\{[^}]+\\}|[^ ]+)");
	
	public static CompiledMessage compile(String messageTemplate) {
		Matcher matcher = pattern.matcher(messageTemplate);
		CompiledMessage message = new CompiledMessage();
		
		int start = 0; 
		int end = 0; 
		while (matcher.find()) {
			start = matcher.start();
			if (start != end) {
				message.addString(messageTemplate.substring(end, start));
			}
			end = matcher.end();
			if (messageTemplate.charAt(start + 1) == '{') { // ${param} syntax
				message.addCompiledExpression(messageTemplate.substring(start + 2, end - 1));
			} else { // $param syntax
				message.addCompiledExpression(messageTemplate.substring(start + 1, end));
			}
		}
		if (end < messageTemplate.length()) {
			message.addString(messageTemplate.substring(end, messageTemplate.length()));
		}
		return message;
	}
	
}
