/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.i18n;


/**
 * The strategy that decides what to do with missing strings
 * @author Ignacio Coloma
 *
 */
public interface MissingMessageHandler {

	/**
	 * Decides what to do with missing keys 
	 * @param missingKey the key that could not be found
	 * @return The substitution value. Could also decide to throw an exception instead 
	 */
	public String handleMissingKey(String missingKey);
	
	/**
	 * Decides what to do with missing parameters
	 * @param missingParamName the param that could not be found (nor any substring of it)
	 * @return The substitution value. Could also decide to throw an exception instead
	 */
	public String handleMissingParameter(String missingParamName);

	/**
	 * Decides what to do with missing/malformed message keys
	 * @param messageKey the key of the message that is missing/malformed
	 * @return The substitution value. Could also decide to throw an exception isntead of returning anything
	 */
	public String handleMessageError(String messageKey, Throwable error);
	
}
