package org.loom.interceptor;

import javax.annotation.PostConstruct;

import org.loom.annotation.SSLPolicyType;
import org.loom.servlet.LoomServletRequest;

/**
 * Uses a different server name for http and https requests. Notice that using this 
 * interceptor implies considerations about the user session, which may be lost between 
 * redirects.
 * @author icoloma
 */
public class MultihostSSLPolicyInterceptor extends SSLPolicyInterceptor {

	/** the server name to use for SSL requests */
	private String httpsServer;
	
	/** the server name to use for non-SSL requests */
	private String httpServer;
	
	/** the server name that will be used for redirects etc */
	private String serverName;
	
	@PostConstruct 
	public  void validateServerNames() {
		if (httpsServer == null || httpServer == null) {
			throw new IllegalArgumentException("Both httpsServer and httpServer are required");
		}
	}
	
	@Override
	public void setPolicy(SSLPolicyType policy) {
		super.setPolicy(policy);
		switch (policy) {
		case REQUIRES_INSECURE:
			serverName = httpServer;
			break;
		case REQUIRES_SECURE:
			serverName = httpsServer;
			break;
		case DO_NOT_MODIFY:
			serverName = null;
			break;
		default:
			throw new IllegalArgumentException();
		}
	}
	
	@Override
	protected String getServerName(LoomServletRequest request) {
		return serverName;
	}
}
