package org.loom.paged;

import org.codehaus.jackson.annotate.JsonProperty;


/**
 * Parent of both request and response objects
 * @author icoloma
 *
 */
public abstract class AbstractPagedContainer implements PagedContainer {
	
	/** the size of each page */
	private int pageSize = DEFAULT_PAGE_SIZE;
	
	/** the id of the paged container. This value will be used to disambiguate if more than one container is used on the same page */
	protected String id;
	
	/** the index of the current page, starts with 0 */
	private int pageIndex = 0;
	
	/** sort direction */
	private SortOrder sortOrder = SortOrder.ASCENDING;

	/** sort property name */
	private String sortProperty;

	/**
	 * @return the zero-based index of the first record that is returned. Internally, it multiplies the page index and the page size.
	 */
	public int getRecordIndex() {
		return getPageIndex() * getPageSize();
	}
	
	public void setPageSize(int pageSize) {
		this.pageSize = pageSize;
	}

	@JsonProperty
	public int getPageIndex() {
		return pageIndex;
	}

	public void setPageIndex(int pageIndex) {
		this.pageIndex = pageIndex;
	}

	public SortOrder getSortOrder() {
		return sortOrder;
	}

	public void setSortOrder(SortOrder sortOrder) {
		this.sortOrder = sortOrder;
	}

	public String getSortProperty() {
		return sortProperty;
	}

	public void setSortProperty(String sortProperty) {
		this.sortProperty = sortProperty;
	}
	
	public int getPageSize() {
		return pageSize;
	}

	public String getId() {
		return id;
	}
	
	public AbstractPagedContainer setId(String id) {
		this.id = id;
		return this;
	}

}
