package org.loom.paged;

import java.util.List;

/**
 * Criteria of a requested page
 * @author icoloma
 *
 */
public interface PagedListCriteria extends PagedContainer {

	/**
	 * Add a parameter to the query
	 * @param paramValue the value of the parameter 
	 */
	public PagedListCriteria addParameter(Object paramValue);
	
	/**
	 * @return the user-specified query, after adding the ORDER BY clause specified by sortProperty and sortOrder
	 */
	public String getOrderedQuery();

	/**
	 * Set the query to be executed, and any additional parameter as well.
	 * The params can also be set latter by invoking addParameter()
	 * @param query the JPA query to execute
	 * @param params the parameters to add to the query, in the expected order
	 */
	public PagedListCriteria setQuery(String query, Object... params);

	/**
	 * Adds the order by parameter to a query. If there is already an
	 * order by, <b>prepends</b> the current order to the one included
	 * in the query
	 */
	public String addOrderBy(String query);

	public List<Object> getParameters();

	/**
	 * @return true if the total should be calculated
	 */
	public boolean calculateTotal();
	
	/**
	 * @deprecated use calculateTotal() instead
	 */
	public boolean isCalculateTotal();
	
	/**
	 * Set the number or results per page to return
	 */
	public void setPageSize(int pageSize);

}
