package org.loom.paged;

import org.loom.exception.HttpException;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.names.RequestParameterNames;

public class PagedListCriteriaFactory {
	
	/**
	 * Create a criteria instance for the current request
	 * @param request the current request object
	 */
	public static PagedListCriteria create (LoomServletRequest request) {
		return create(request, null);
	}
	
	/**
	 * Create a criteria instance for the current request, with disambiguation
	 * @param request the current request object
	 * @param id the paged container id. Null if there is only one paged container in this page.
	 */
	public static PagedListCriteria create (LoomServletRequest request, String id) {
		PagedListCriteriaImpl criteria = new PagedListCriteriaImpl();
		criteria.setId(id);
		String pi = id == null? RequestParameterNames.PAGED_INDEX : RequestParameterNames.PAGED_INDEX + "-" + id;
		String sp = id == null? RequestParameterNames.PAGED_SORT_PROPERTY : RequestParameterNames.PAGED_SORT_PROPERTY + "-" + id;
		String pso = id == null? RequestParameterNames.PAGED_SORT_ORDER : RequestParameterNames.PAGED_SORT_ORDER + "-" + id;
		
		String s = request.getParameter(pi);
		if (s != null) {
			try {
				criteria.setPageIndex(Integer.parseInt(s));
			} catch (NumberFormatException e) {
				throw new HttpException(400, "Malformed value specified for " + pi, e);
			}
		}
		criteria.setSortProperty(request.getParameter(sp));
		criteria.setSortOrder(SortOrder.fromValue(request.getParameter(pso)));
		return criteria;
	}
	
}
