package org.loom.paged;

import java.util.ArrayList;
import java.util.List;

import org.codehaus.jackson.annotate.JsonAutoDetect;
import org.codehaus.jackson.annotate.JsonMethod;
import org.codehaus.jackson.annotate.JsonProperty;

import com.google.common.collect.ImmutableList;

/**
 * The data of a paged list
 * @author icoloma
 *
 */
@JsonAutoDetect(JsonMethod.NONE)
public class PagedListDataImpl<T> extends AbstractPagedContainer implements PagedListData<T>, Cloneable {

	/** an empty list of Object */
	public static final PagedListData<?> EMPTY_LIST;
	
	/** the list of data in the current page */
	private List<T> data;
	
	/** the total number of records */
	private int totalRecords;
	
	/** the total number of pages, -1 if not initialized */
	private int totalPages = -1;

	static {
		PagedListDataImpl<Object> l = new PagedListDataImpl<Object>();
		l.setData(ImmutableList.of());
		l.setTotalRecords(0);
		EMPTY_LIST = l;
	}
	
	public PagedListDataImpl() {
	}
	
	@Override
	@SuppressWarnings("unchecked")
	public PagedListDataImpl<T> clone() {
		try {
			PagedListDataImpl<T> result = (PagedListDataImpl<T>) super.clone();
			result.setData(new ArrayList<T>(data));
			return result;
		} catch (CloneNotSupportedException e) {
			throw new RuntimeException(e);
		}
	}

	public void setTotalRecords(Integer pagedListSize) {
		this.totalRecords = pagedListSize;
		this.totalPages = (int) Math.ceil((double)totalRecords / getPageSize());
	}
	
	/**
	 * @return the zero-based index of the first record on the next page. 
	 */
	public int getNextPageRecordIndex() {
		int last = getRecordIndex() + getPageSize();
		return Math.min(last, totalRecords);
	}

	/**
	 * @return true if the list of returned data is empty
	 */
	public boolean isEmpty() {
		return data == null || data.isEmpty();
	}
	
	@JsonProperty 
	public List<T> getData() {
		return data;
	}
	
	public void setData(List<T> data) {
		this.data = data;
	}
	
	@JsonProperty("totalResults")
	public int getTotalRecords() {
		return totalRecords;
	}
	
	@JsonProperty 
	public int getTotalPages() {
		return totalPages;
	}	
	
	@Override
	@SuppressWarnings("unchecked")
	public PagedListDataImpl<T> setId(String id) {
		return (PagedListDataImpl<T>) super.setId(id);
	}

}
