package org.loom.paged;

import java.util.Comparator;

import org.loom.binding.PropertyBinder;
import org.loom.binding.PropertyBinderFactory;
import org.loom.config.Config;

/**
 * Compares list items for web layer based sorting and pagination
 * Note that this Comparator class requires that the property used for sorting implements Comparable
 * @author icoloma
 *
 */
public class PagedListItemComparator<T> implements Comparator<T> {

	/** the order of the sorting */
	private SortOrder sortOrder;

	/** the propertyBinder that handles the sort property */
	private PropertyBinder propertyBinder;
	
	public PagedListItemComparator(Class<T> itemClass, String sortProperty, SortOrder sortOrder) {
		this.sortOrder = sortOrder;
		PropertyBinderFactory factory = new PropertyBinderFactory();
		factory.setPropertyWrapperFactory(Config.getInstance().getPropertyWrapperFactory());
		this.propertyBinder = factory.create(itemClass, sortProperty);
	}

	@SuppressWarnings("unchecked")
	public int compare(T o1, T o2) {
		int result;
		if (o1 == null) {
			result = o2 == null? 0 : 1;
		} else {
			Object v1 = propertyBinder.getValue(o1, propertyBinder.getNormalizedPropertyPath());
			Object v2 = propertyBinder.getValue(o2, propertyBinder.getNormalizedPropertyPath());
			result = ((Comparable) v1).compareTo(v2);
		}
		return sortOrder == SortOrder.ASCENDING? result : -result;
	}
	
}
