package org.loom.persistence;

import javax.persistence.EntityManager;

import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.ejb.HibernateEntityManager;
import org.hibernate.metadata.ClassMetadata;

/**
 * Extended entity manager operations for the Hibernate JPA Implementation.
 * @author icoloma
 *
 */
public class HibernateExtendedEntityManagerImpl extends AbstractExtendedEntityManager implements HibernateExtendedEntityManager {

	public HibernateExtendedEntityManagerImpl(EntityManager entityManager) {
		super(entityManager);
	}

	public String getIdPropertyName(Class<?> clazz) {
		ClassMetadata metadata = getSessionFactory().getClassMetadata(clazz);
		return metadata.getIdentifierPropertyName();
	}
	
	public String getVersionPropertyName(Class<?> clazz) {
		ClassMetadata metadata = getSessionFactory().getClassMetadata(clazz);
		int versionPropertyIndex = metadata.getVersionProperty();
		if (versionPropertyIndex < 0) {
			return null;
		}
		return metadata.getPropertyNames()[versionPropertyIndex];
	}
	
	@SuppressWarnings("unchecked")
	public <T> T getVersionValue(Object o) {
		ClassMetadata metadata = getSessionFactory().getClassMetadata(o.getClass());
		return (T) metadata.getVersion(o, getSession().getEntityMode());
	}
	
	public void evict(Object o) {
		getSession().evict(o);
	}

	public void setReadOnly(Object instance, boolean readOnly) {
		getSession().setReadOnly(instance, readOnly);
	}
	
	public Session getSession() {
		return ((HibernateEntityManager) getEntityManager()).getSession();
	}
	
	private SessionFactory getSessionFactory() {
		return getSession().getSessionFactory();
	}
}
