/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.persistence.file;

import java.io.IOException;
import java.io.InputStream;

import org.springframework.core.io.AbstractResource;

/**
 * Adapter from PersistentFile to Spring Resource API
 * @author icoloma
 */
public class PersistentFileResource extends AbstractResource {

	private final PersistentFile file;

	public PersistentFileResource(PersistentFile file) {
		this.file = file;
	}

	/**
	 * This implementation always returns <code>true</code>.
	 */
	public boolean exists() {
		return true;
	}

	/**
	 * This implementation always returns <code>false</code>.
	 */
	public boolean isOpen() {
		return false;
	}

	public InputStream getInputStream() throws IOException, IllegalStateException {
		return file.getContentsAsStream();
	}

	/**
	 * This implementation returns the passed-in description, if any.
	 */
	public String getDescription() {
		return "persistent file '" + file.getFilename() + "'";
	}


	/**
	 * This implementation compares the underlying InputStream.
	 */
	public boolean equals(Object obj) {
		return (obj == this ||
		    (obj instanceof PersistentFileResource && ((PersistentFileResource) obj).file.equals(this.file)));
	}

	/**
	 * This implementation returns the hash code of the underlying InputStream.
	 */
	public int hashCode() {
		return this.file.hashCode();
	}

}
