/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import java.awt.image.BufferedImage;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.servlet.ServletException;

import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.util.MimeUtils;

/**
 * Delivers an image to the browser
 * 
 * @author ggarcia
 */
public class BufferedImageResolution extends AbstractHttpResolution {
	
	/** Image data */ 
	private BufferedImage image;
	
	/** Image type, defaults to jpg */
	private String type = "jpg";

	public BufferedImageResolution(BufferedImage image, String type) {
		this.image = image;
		this.type = type;
	}

	public BufferedImageResolution(BufferedImage image) {
		this.image = image;
	}

	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException {
		if (getContentType() == null) {
			setContentType(MimeUtils.guessMimeType(type));
		}
		writeHeaders(request, response);
		ImageIO.write(image, type, response.getOutputStream());
	}

	public BufferedImage getImage() {
		return image;
	}

	public void setImage(BufferedImage image) {
		this.image = image;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}
	
}
