/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import static org.loom.util.FileUtils.copy;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.servlet.ServletException;

import org.apache.commons.io.IOUtils;
import org.loom.persistence.file.PersistentFile;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;


/**
 * Delivers a {@link PersistentFile} to the browser
 * @author icoloma
 */
public class PersistentFileResolution extends AbstractFileResolution {

	/** the file to deliver to the browser */
	private PersistentFile persistentFile;

	public PersistentFileResolution(PersistentFile persistentFile) {
		if (persistentFile == null) {
			throw new IllegalArgumentException("persistentFile cannot be null");
		}
		this.persistentFile = persistentFile;
		this.setFilename(persistentFile.getFilename());
		this.setContentType(persistentFile.getContentType());
		this.setFileSize(persistentFile.getFileSize());
	}
	
	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException {
		writeHeaders(request, response);
		InputStream input = null;
		try {
			input = persistentFile.getContents().getContentsAsStream();
			OutputStream output = response.getOutputStream(); 
			copy(input, output);
		} finally {
			IOUtils.closeQuietly(input);
		}
	}
	
	public PersistentFile getPersistentFile() {
		return persistentFile;
	}
}
