package org.loom.resources;

import java.io.InputStream;


/**
 * The contents of a web resource (javascript or css file)
 * This class may contain the result of the concatenation and
 * minification (obfuscation) of multiple files, and should be immutable.
 * 
 * Thios object offers a way to retrieve the plain file contents and the 
 * equivalent gzipped version, which should be calculated in advance as 
 * gzip-enabled agents are the most common case.
 * 
 * @author icoloma
 */
public interface WebResourceData {

	/**
	 * @return the calculated MD5 hash of this file
	 */
	public String getMd5();
	
	/**
	 * @return a stream to retrieve the resource data
	 */
	public InputStream getInputStream();
	
	/**
	 * @return a stream to retrieve a gzipped version of the resource data
	 */
	public InputStream getGzippedInputStream();

	/**
	 * @return the length of the resource data file
	 */
	public long getLength();
	
	/**
	 * @return the length of the gzipped resource data file
	 */
	public long getGzippedLength();
	
	/**
	 * @return The resource type.
	 */
	public WebResourceType getType();

	/**
	 * @return the response charset to use
	 */
	public String getCharset();
	
	/**
	 * @return the {@link WebResource} instance from which this data has been created
	 */
	public WebResource getWebResource();
	
}
