package org.loom.resources.compressor;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;

import org.loom.exception.SyntaxError;
import org.loom.log.Log;
import org.mozilla.javascript.ErrorReporter;
import org.mozilla.javascript.EvaluatorException;

import com.yahoo.platform.yui.compressor.JavaScriptCompressor;

/**
 * Adapter for the javascript YUICompressor 
 * @author icoloma
 */
public class YuiJavascriptCompressorAdapter implements WebResourceCompressor {
	
	/** verbose output, default false */
	private boolean verbose;
	
	/** preserve all semicolons, default false */
	private boolean preserveAllSemiColons;
	
	/** * disable all micro optimizations, default false.*/
	private boolean disableOptimizations;
	
	/** obfuscate, default true. Disable to keep the javascript method and variable names */
	private boolean munge = true;
	
	/** insert a line break after the specified column number, default -1 */
	private int lineBreakColumn = -1;
	
	private static Log log = Log.getLog();
	
	private static ErrorReporter errorReporter = new YuiErrorReporter(log);
	
	public void compress(InputStream input, OutputStream output) throws IOException, SyntaxError {

		try {
			// note that I don't close either reader or writer. The underlying streams will
			// be closed by the caller, and these two will be garbage collected.
			InputStreamReader reader = new InputStreamReader(input);
			OutputStreamWriter writer = new OutputStreamWriter(output);
			JavaScriptCompressor compressor = new JavaScriptCompressor(reader, errorReporter);
			compressor.compress(writer, lineBreakColumn, munge, verbose, preserveAllSemiColons, disableOptimizations);
			writer.flush();
		} catch (EvaluatorException e) {
			throw new SyntaxError(e);
		}
		
		
	}

	public boolean isVerbose() {
		return verbose;
	}

	public void setVerbose(boolean verbose) {
		this.verbose = verbose;
	}

	public boolean isPreserveAllSemiColons() {
		return preserveAllSemiColons;
	}

	public void setPreserveAllSemiColons(boolean preserveAllSemiColons) {
		this.preserveAllSemiColons = preserveAllSemiColons;
	}

	public boolean isDisableOptimizations() {
		return disableOptimizations;
	}

	public void setDisableOptimizations(boolean disableOptimizations) {
		this.disableOptimizations = disableOptimizations;
	}

	public boolean isMunge() {
		return munge;
	}

	public void setMunge(boolean munge) {
		this.munge = munge;
	}

	public int getLineBreakColumn() {
		return lineBreakColumn;
	}

	public void setLineBreakColumn(int lineBreakColumn) {
		this.lineBreakColumn = lineBreakColumn;
	}

}
