/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.security;

import org.springframework.security.core.GrantedAuthority;

/**
 * Common security API for  custom security providers 
 * @author icoloma
 */
public interface SecurityAdapter {
	
	/**
	 * Iterates the list of {@link GrantedAuthority} for this user, and returns
	 * true if one of them is included in the list of authorized roles.
	 * @param allowedRoles the list of roles to check. 
	 * @return true if any of the provided roles is associated to the current 
	 * request principal, false otherwise.
	 */
	boolean hasRole(String[] allowedRoles);

	/**
	 * Throw a provider-specific exception for not enough permissions. 
	 */
	void throwInsufficientPermissionsException(String message);
	
}
