/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet;

import javax.servlet.http.HttpServletResponse;

/**
 * An enhanced implementation of the HttpServletResponse interface
 * @author icoloma
 *
 */
public interface LoomServletResponse extends HttpServletResponse {

	/**
	 * Delete a cookie from the browser
	 * @param name the name of the cookie to delete
	 */
	public void deleteCookie(String name);

	/**
	 * Note that this method will only return the status if it has been set 
	 * through this wrapper. Sometimes the server will change the status using the 
	 * underlying response instance.
	 * @return the status of this response object (200, 404, etc)
	 */
	public int getStatus();

	/**
	 * Add a {@link ResponseListener} instance that will get notified about servlet response events
	 * @param listener the instance to notify.
	 */
	public void addListener(ResponseListener listener);
	
}