/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet.names;


/**
 * GET / POST parameter names used by Loom
 * @author Ignacio Coloma
 */
public final class RequestParameterNames {
	
	/** the prefix of internal Loom parameters */
	public static final String LOOM_PREFIX = "_";
	
	/** if present, override the HTTP method being invoked (to use DELETE or PUT from a browser request)
	 * Note that by default this is the same parameter name used by prototype Ajax requests */
	public static final String METHOD_OVERRIDES = LOOM_PREFIX + "mth";
	
	/** prefix used for multiple submit button to override the target event */
	public static final String OVERRIDE_EVENT_PREFIX = LOOM_PREFIX + "event-";
	
	/** flash scope ID */
	public static final String FLASH_ID = LOOM_PREFIX + "fl";
	
	/** in paged listings, the sort property */
	public static final String PAGED_SORT_PROPERTY = LOOM_PREFIX + "paged-sortby";
	
	/** in paged listings, the sort order (asc, desc) */
	public static final String PAGED_SORT_ORDER = LOOM_PREFIX + "paged-sort";
	
	/** in paged listings, the sort order (asc, desc) */
	public static final String PAGED_INDEX = LOOM_PREFIX + "paged-index";

	/** for SingleUseToken events, the token name */
	public static final String SINGLE_USE_TOKEN = LOOM_PREFIX + "token";
	
	/** when redirecting because an error, this parameter is true */
	public static final String REDIRECT_ERROR = LOOM_PREFIX + "err";

	private RequestParameterNames() {}
	
	/**
	 * Return true if the provided parameter name is a Loom internal parameter
	 */
	public static boolean isInternal(String paramName) {
		return paramName.length() > 1 && paramName.charAt(0) == '_';
	}
	
}
