/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.exception;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.SimpleTagSupport;

import org.loom.tags.JspWriterWrapper;
import org.loom.tags.WriterWrapper;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;


/**
 * Display an http error or exception to the user.
 * This tag delegates to ErrorRenderer.
 * @author icoloma
 */
@Tag(
		bodyContent=BodyContent.EMPTY
	)
public class ExceptionTag extends SimpleTagSupport {

	private ErrorRenderer renderer = new DefaultErrorRenderer();
	
	@Override
	public void doTag() throws JspException, IOException {
		PageContext context = (PageContext)getJspContext();
		HttpServletRequest request = (HttpServletRequest) context.getRequest();
		WriterWrapper<?> writer = new JspWriterWrapper(context.getOut());
		renderer.renderError(writer, request);
	}
	
	/** 
	 * true to log the request contents (headers, parameters, attributes) 
	 * when logging any exception, default false 
	 */
	@Attribute
	public void setLogRequest(boolean logRequest) {
		renderer.setLogRequest(logRequest);
	}
	
	/** 
	 * The HTML tag used to render the error message (exception message or http error message), 
	 * empty or null to skip error message, default h1 
	 */
	@Attribute
	public void setMessageTag(String messageTag) {
		renderer.setTitleTag(messageTag);
	}

}
