/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.menu;

import static org.loom.servlet.names.CssClassNames.UNAUTHORIZED;

import java.io.IOException;
import java.util.Iterator;

import javax.servlet.jsp.JspException;

import org.loom.servlet.LoomServletRequest;
import org.loom.tags.WriterWrapper;
import org.loom.tags.core.UrlTag;

/**
 * Decorates menu items as an list of links.
 * @author icoloma
 */
public class InlineMenuDecorator extends AbstractMenuDecorator {

	public boolean beforeDoTag(MenuTag tag) throws IOException,
	JspException {
		return true;
	}
	
	public void afterDoTag(MenuTag tag) throws IOException, JspException {
		LoomServletRequest request = tag.getRequest();
		AbstractMenuData menu = tag.getMenu();
		
		WriterWrapper<?> out = tag.getWriter();
		out.start("div", "id", menu.getId(), "class", menu.getCssClass());
		
		// print the list of items
		MenuItemData selectedItem = menu.getSelectedItem(tag.getRequest());
		String itemSeparator = tag.getItemSeparator();
		boolean first = true;
		for (Iterator<MenuItemData> i = menu.getChildren().iterator(); i.hasNext();) {
			MenuItemData item = i.next();

			// calculate the url
			UrlTag urlTag = item.getUrlTag(request, tag.getResponse());
			if (isRenderUnauthorizedItems() || !urlTag.getCssBuilder().contains(UNAUTHORIZED)) {
				
				// print the separator.
				// it must be done here to avoid printing separators between items
				// that are not rendered for being unauthorized
				if (itemSeparator != null) {
					if (first) {
						first = false;
					} else {
						out.print(itemSeparator);
					}
				}
				
				urlTag.setWriter(tag.getWriter());
				if (selectedItem == item) {
					urlTag.addCssClass("selected");
				}
				urlTag.doTagImpl();
				
			}
		}
		out.print("</div>");
		
	}

}
