/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.menu;

import java.util.Locale;

import org.loom.servlet.LoomServletRequest;

/**
 * Locale menu data.
 * @author icoloma
 */
public class LocaleMenuData extends AbstractMenuData {

	/** true if the locale is used to translate the locale name, e.g. Español against Spanish */
	private boolean selfTranslated = true;
	
	/**
	 * Returns the selected item, considering language, country and variant.
	 * If nothing matches, returns null.
	 */
	@Override
	public MenuItemData getSelectedItem(LoomServletRequest request) {
		MenuItemData bestFit = null;
		// the number of fields that matches
		int score = 0;
		Locale locale = request.getLocale();
		String lang = locale.getLanguage();
		String country = locale.getCountry();
		String variant = locale.getVariant();
		for (MenuItemData candidate : getItems()) {
			Locale candidateLocale = ((LocaleMenuItemData)candidate).getLocale();
			if (candidateLocale.getLanguage().equals(lang)) {
				int newScore = 1;
				if (candidateLocale.getCountry().equals(country)) {
					newScore++;
					if (candidateLocale.getVariant().equals(variant)) {
						newScore++;
					} else if (candidateLocale.getCountry().length() > 0) {
						// if the candidate has specified a variant that does not match, it does not fit
						newScore = 0;
					}
				} else if (candidateLocale.getCountry().length() > 0) {
					// if the candidate has specified a country that does not match, it does not fit
					newScore = 0;
				}
				if (newScore > score) {
					score = newScore;
					bestFit = candidate;
				}
			}
		}
		return bestFit;
	}

	public boolean isSelfTranslated() {
		return selfTranslated;
	}

	public void setSelfTranslated(boolean selfTranslated) {
		this.selfTranslated = selfTranslated;
	}
	
}
