package org.loom.tags.messages;

import java.lang.reflect.Method;
import java.util.Date;

import org.apache.commons.lang.StringUtils;
import org.joda.time.Period;
import org.joda.time.PeriodType;
import org.loom.i18n.Message;
import org.loom.util.ClassUtils;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Format a Date in minutes/hours/days etc, relative to today.
 * Equivalent to <a href="http://api.rubyonrails.org/classes/ActionView/Helpers/DateHelper.html#M001696">DateHelper.time_ago_in_words</a> in Ruby
 * and Date.humanized in format.js
 * @author icoloma
 *
 */
@Tag(
		bodyContent=BodyContent.SCRIPTLESS,
		example="&lt;l:formatDate value=\"${myDate}\"/>"
	)
public class FormatDateTag extends AbstractFormatTag {
	
	/** value to format */
	@Attribute(required=true)
	private Date value;

	/** the metadata of Duration getters to use */
	private static Method[] getterMetadata;
	
	static {
		try {
			getterMetadata = new Method[7];
			getterMetadata[0] = Period.class.getMethod("getYears");
			getterMetadata[1] = Period.class.getMethod("getMonths");
			getterMetadata[2] = Period.class.getMethod("getWeeks");
			getterMetadata[3] = Period.class.getMethod("getDays");
			getterMetadata[4] = Period.class.getMethod("getHours");
			getterMetadata[5] = Period.class.getMethod("getMinutes");
			getterMetadata[6] = Period.class.getMethod("getSeconds");
		} catch (NoSuchMethodException e) {
			throw new RuntimeException(e);
		}
	}
	
	@Override
	public String format() {
		Date d1;
		Date d2 = new Date();
		boolean future;
		if (value.after(d2)) {
			d1 = value;
			future = true;
		} else {
			d1 = d2;
			d2 = value;
			future = false;
		}
		
		String[] unitNames = StringUtils.split(repository.getString("loom.format.timeUnitNames"), ' ');
		String[] singularUnitNames = StringUtils.split(repository.getString("loom.format.singularTimeUnitNames"), ' ');

		Period period = new Period(d2.getTime(), d1.getTime(), PeriodType.yearMonthDayTime());
		int amount = 0;
		String unitName;
		String messageKey = future? "loom.format.future" : "loom.format.past";
		for (int i = 0; /*i < getterMetadata.length*/; i++) {
			Method getter = getterMetadata[i];
			amount = (Integer) ClassUtils.invoke(period, getter);
			if (amount > 0 || i == getterMetadata.length - 1) {
				unitName = amount == 1? singularUnitNames[i] : unitNames[i];
				if (i == getterMetadata.length - 1) {
					messageKey += ".seconds";
				}
				break;
			}
		}
		
		if (amount == 0) {
			amount = period.getSeconds();
		}
		
		Message message = new Message(messageKey);
		message.addArg("amount", amount);
		message.addArg("unitName", unitName);
		return repository.translateMessage(message);
	}


	public void setValue(Date value) {
		this.value = value;
	}
	
}
