package org.loom.tags.paged;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.i18n.Message;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Contains a PagedListData of objects to be rendered as a &lt;ul>
 * 
 * @author icoloma
 *
 */
@Tag(
		dynamicAttributes=true, 
		bodyContent=BodyContent.SCRIPTLESS,
		example=
		"&lt;l:pagedList data=\"${action.customers}\" linksPosition=\"both\">\n" +
		"  &lt;l:url action=\"Customers\" event=\"edit\">\n" +
		"     &lt;l:param name=\"customer.id\" value=\"${row.id}\"/>\n" +
		"     &lt;strong>${row.id}&lt;/strong> - ${row.firstName}\n" +
		"  &lt;/l:url>\n" +
		"&lt;/l:pagedList>"
	)
public class PagedListTag extends AbstractPagedContainerTag {

	@Override
	protected void renderHeader() throws IOException, JspException {
		out.print("<ul").printAttribute("id", getId()).printAttribute("class", "data").print(">\n");
	}
	
	@Override
	protected void renderEmptyContainer() throws IOException, JspException {
		out.print(repository.translateMessage(new Message(getMessagePrefix() + "empty")));
	}
	
	@Override
	protected void renderFooter() throws IOException, JspException {
		out.print("</ul>\n");
	}
	
	@Override
	protected void renderRowStart() throws IOException, JspException {
		out.print("<li").printAttribute("class", getRowClass()).print(">");
	}
	
	@Override
	protected void renderRowEnd() throws IOException, JspException {
		out.print("</li>\n");
	}

}
