/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.tabs;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.jsp.JspException;

import org.loom.tags.AbstractDecoratedTag;
import org.loom.tags.WriterWrapper;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * Container for a group of tabs.  
 * @author icoloma
 */
@Tag(
		dynamicAttributes=true, 
		bodyContent=BodyContent.SCRIPTLESS,
		example="see <a href=\"tab.html\">tab</a>"
	)
public class TabContainerTag extends AbstractDecoratedTag {

	/** id of this tab group */
	@Attribute
	private String id;
	
	/** list of tabs to be written */
	private List<TabTag> tabs = new ArrayList<TabTag>();
	
	@Override
	public void doTagImpl() throws JspException, IOException {
		String body = doBufferedBody();
		printTabHeaders(out);
		out.print(body);
	}

	/**
	 * Print tab headers
	 */
	private void printTabHeaders(WriterWrapper<?> out) throws IOException, JspException {
		if (tabs.size() == 0) {
			return;
		}
		
		out.print("<ul");
		out.printAttribute("id", id);
		out.printAttribute("class", "tabContainer");
		out.print(">\n");
		
		for (TabTag	tab : tabs) {
			TabDecorator decorator = (TabDecorator) tab.getDecoratorInstance();
			decorator.printTabHeader(out, repository, tab);
		}
		out.print("</ul>\n");
	}

	public void addTab(TabTag tab) {
		tabs.add(tab);
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	
}
